@@ -65,3 +65,31 @@ class Vectorshift():
         }
         return requests.post('https://api.vector-shift.com/api/transformations/user/create',
                              data={'transformation': json.dumps(transformation_params), 'api_key': self.api_key})
+
+    def run_transformation(self,
+                           id: str = '',
+                           name: str = '',
+                           inputs: dict = {}):
+        query_dict = {'id': id, 'name': name}
+        query_params = f'''?{'&'.join([f'{k}={v}' for k, v in query_dict.items() if v != ''])}'''
+        response = requests.post(f'https://api.vector-shift.com/api/transformations/user/run{query_params}',
+                             data={'inputs': json.dumps(inputs), 'api_key': self.api_key}).text
+        return json.loads(response)
+
+    def get_source_info(self,
+                        id: str = '',
+                        name: str = ''):
+        query_dict = {'id': id, 'name': name}
+        query_params = f'''?{'&'.join([f'{k}={v}' for k, v in query_dict.items() if v != ''])}'''
+        response = requests.get(f'https://api.vector-shift.com/api/sources/info{query_params}',
+                            data={'api_key': self.api_key}).text
+        return json.loads(response)
+
+    def get_transformation_info(self,
+                                id: str = '',
+                                name: str = ''):
+        query_dict = {'id': id, 'name': name}
+        query_params = f'''?{'&'.join([f'{k}={v}' for k, v in query_dict.items() if v != ''])}'''
+        response = requests.get(f'https://api.vector-shift.com/api/transformations/user/info{query_params}',
+                            data={'api_key': self.api_key}).text
+        return json.loads(response)
